@@ -1,21 +1,46 @@
 package Padre::Plugin::XS::Document;
-BEGIN {
-  $Padre::Plugin::XS::Document::VERSION = '0.09';
-}
 
-# ABSTRACT: Padre XS Document
-
-use 5.008;
+use v5.10.1;
 use strict;
 use warnings;
-use Padre::Document ();
 
-our @ISA = 'Padre::Document';
+use Padre::Logger;
+use YAML::Tiny;
+
+our $VERSION = '0.10';
+use parent qw(Padre::Document);
+
+#######
+# Task Integration
+#######
+sub task_functions {
+	return '';
+}
+
+sub task_outline {
+	return '';
+}
+
+sub task_syntax {
+#	return 'Padre::Plugin::YAML::Syntax';
+	return '';
+}
+
+# sub comment_lines_str {
+	# return '#';
+# }
+
+
+
+#######
+# Padre-Document Overloading
+#######
 
 # TODO better highlighting. Can vim do better? Can we steal? Add an STC highlighter? ...
 
-sub keywords {
+sub get_calltip_keywords {
 	my $self = shift;
+	TRACE("get_calltip_keywords called") if DEBUG;
 
 	if ( not defined $self->{_perlapi_keywords} ) {
 		$self->_load_perlapi_keywords();
@@ -34,79 +59,91 @@ sub keywords {
 sub _load_perlapi_keywords {
 	my $self = shift;
 
-	if ( not eval "use Perl::APIReference 0.03; 1;" ) {
+	if ( not eval {use Perl::APIReference 0.03; 1;} ) {
+		TRACE('Perl::APIReference failed') if DEBUG;
 		$self->{_perlapi_keywords} =
-			YAML::Tiny::LoadFile( Padre::Util::sharefile( 'languages', 'perl5', 'perlapi_current.yml' ) );
+			YAML::Tiny::LoadFile( Padre::Util::sharefile( 'languages', 'perl5', 'perl5.yml', 'perlapi_current.yml' ) );
 		return;
 	}
 
 	my $perl_version = $self->{_perlapi_version};
-
+# p $perl_version;
 	if ( not defined $perl_version ) {
 		my $project = $self->project;
 		if ( defined $project ) {
 			$perl_version = 'newest';
 			my $cfg = $project->config;
-			$perl_version = $cfg->xs_calltips_perlapi_version();
+			$perl_version = $cfg->xs_calltips_perlapi_version(); # this is = 'newest'
 		} else {
 			$perl_version = Padre->ide->config->xs_calltips_perlapi_version();
 		}
 		$self->{_perlapi_version} = $perl_version;
 	}
-
+# p $perl_version;
 	my $apiref = eval { Perl::APIReference->new( perl_version => $perl_version ) };
+# p $apiref;
 	if ( not $apiref ) {
 
 		# fallback...
 		$self->{_perlapi_keywords} =
-			YAML::Tiny::LoadFile( Padre::Util::sharefile( 'languages', 'perl5', 'perlapi_current.yml' ) );
+			YAML::Tiny::LoadFile( Padre::Util::sharefile( 'languages', 'perl5', 'perl5.yml', 'perlapi_current.yml' ) );
 		return;
 	}
 
 	# TODO: Perl::APIReference also provides an "index" method, but that doesn't return the structure
 	#       in exactly the way we want it. Easy way out: Add an accessor to Perl::APIReference that
 	#       returns an API structure akin to what would be returned by loading the YAML.
-	require YAML::Tiny;
+#	require YAML::Tiny;
 	$self->{_perlapi_keywords} = YAML::Tiny::Load( $apiref->as_yaml_calltips );
+# p $self->{_perlapi_keywords};
 	return;
 }
 
 1;
 
-
+__END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
-Padre::Plugin::XS::Document - Padre XS Document
+Padre::Plugin::XS::Document - A Padre Document that understands XS
 
 =head1 VERSION
 
-version 0.09
+version: 0.10
 
-=head1 AUTHORS
+=head1 METHODS
 
 =over 4
 
-=item *
+=item * task_functions
 
-Steffen Mueller <smueller@cpan.org>
+=item * task_outline
 
-=item *
+=item * task_syntax
 
-Ahmad M. Zawawi <ahmad.zawawi@gmail.com>
+=item * get_calltip_keywords
 
 =back
 
-=head1 COPYRIGHT AND LICENSE
+=head1 AUTHOR
 
-This software is copyright (c) 2010 by Steffen Mueller.
+See L<Padre::Plugin::XS>
 
-This is free software; you can redistribute it and/or modify it under
-the same terms as the Perl 5 programming language system itself.
+=head2 CONTRIBUTORS
+
+See L<Padre::Plugin::XS>
+
+=head1 COPYRIGHT
+
+See L<Padre::Plugin::XS>
+
+=head1 LICENSE
+
+This library is free software; you can redistribute it and/or modify
+it under the same terms as Perl itself.
 
 =cut
-
-
-__END__
